﻿namespace UltraTimelineViewIssue
{
    using System;
    using System.Drawing;
    using System.Windows.Forms;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinSchedule;

    public partial class Form1 : Form
    {
        public Form1()
        {
            this.InitializeComponent();
            this.Load += Form1_Load;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraTimelineView1.CalendarInfo = this.ultraCalendarInfo1;
            this.ultraTimelineView1.CalendarLook = this.ultraCalendarLook1;

            this.ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;

            this.ultraCalendarLook1.ViewStyle = ViewStyle.Office2007;

            this.AddData();
            this.SetAllDayAppointmentsAppearancePerOwner(this.ultraCalendarInfo1);
        }

        private void AddData()
        {
            var ownerJohn = this.ultraCalendarInfo1.Owners.Add("John");
            var ownerAnn = this.ultraCalendarInfo1.Owners.Add("Ann");

            var johnAllDayAppointment = this.ultraCalendarInfo1.Appointments.Add(
                DateTime.Today,
                DateTime.Today.AddDays(3),
                "John's all day appointment");
            johnAllDayAppointment.AllDayEvent = true;
            johnAllDayAppointment.Owner = ownerJohn;

            var johnNonAllDayAppointment = this.ultraCalendarInfo1.Appointments.Add(
                DateTime.Today,
                DateTime.Today.AddDays(3),
                "John's non-all day appointment");
            johnNonAllDayAppointment.AllDayEvent = false;
            johnNonAllDayAppointment.Owner = ownerJohn;

            var annAllDayAppointment = this.ultraCalendarInfo1.Appointments.Add(
                DateTime.Today.AddDays(-1),
                DateTime.Today.AddDays(3),
                "Ann's all day appointment");
            annAllDayAppointment.AllDayEvent = true;
            annAllDayAppointment.Owner = ownerAnn;

            var annNonAllDayAppointment = this.ultraCalendarInfo1.Appointments.Add(
                DateTime.Today.AddDays(2),
                DateTime.Today.AddDays(5),
                "Ann's non-all day appointment");
            annNonAllDayAppointment.AllDayEvent = false;
            annNonAllDayAppointment.Owner = ownerAnn;
        }

        private void SetAllDayAppointmentsAppearancePerOwner(UltraCalendarInfo calendarInfo)
        {
            var index = 0;

            // Get automatically generated colors used by Office2007 style
            var office2007Colors = this.ultraCalendarLook1.Outlook2007ColorSchemes.SupportedColors;
            foreach (Owner owner in calendarInfo.Owners)
            {
                // If unassigned owner is not visible skip setting its appearance
                if (owner.IsUnassigned == true &&
                    calendarInfo.Owners.UnassignedOwner.Visible == false)
                {
                    continue;
                }

                // Create an instance of Appearance class for the owner
                var ownerHeaderAppearance = new Infragistics.Win.Appearance();

                // If this is the first owner get the appearance from default scheme
                if (index == 0)
                {
                    ownerHeaderAppearance.BackColor = this.ultraCalendarLook1.Outlook2007ColorSchemes.DefaultScheme.HeaderBackColor;
                }
                else
                {
                    ownerHeaderAppearance.BackColor = office2007Colors[index % office2007Colors.Length];
                }

                ownerHeaderAppearance.BackColor2 = Color.White;
                owner.HeaderAppearance = ownerHeaderAppearance;

                // Create an instance of Appearance class for the appointments. We cannot use the same one
                // for appointments and owner as they have different gradient 
                var appointmentAppearance = ownerHeaderAppearance.Clone() as Infragistics.Win.Appearance;

                foreach (Appointment app in owner.GetAppointmentsInRange(DateTime.MinValue, DateTime.MaxValue))
                {
                    appointmentAppearance.BackGradientStyle = GradientStyle.Vertical;
                    app.Appearance = appointmentAppearance;
                }

                index++;
            }
        }
    }
}
